#
# spec file for package python-kiwisolver
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-kiwisolver
Version:        1.1.0
Release:        lp152.1.3
Summary:        An implementation of the Cassowary constraint solver
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/nucleic/kiwi
Source:         https://github.com/nucleic/kiwi/archive/%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Kiwi is a C++ implementation of the Cassowary constraint solving
algorithm. Kiwi is an implementation of the algorithm based on the
seminal Cassowary paper, but it is not a refactoring of the original
C++ solver. Kiwi ranges from 10x to 500x faster processing than the
original Cassowary solver with the same input set, with typical use
cases gaining a 40x improvement. Memory savings are consistently >5x.

In addition to the C++ solver, Kiwi ships with hand-rolled Python bindings.

%prep
%setup -q -n kiwi-%{version}
# Fix wrong-file-end-of-line-encoding
dos2unix LICENSE README.rst releasenotes.rst

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.rst releasenotes.rst
%{python_sitearch}/*

%changelog
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.0:
  * prevent attempting a dual optimize on a dummy row PR #56 closes #15
  * add dump and dumps methods to inspect the internal state of the solver PR #56
  * test on Python 3.7 PR #51
  * improvemnts to setup.py and tests PR #46 #50
* Wed Mar 28 2018 jengelh@inai.de
- Quantify speeds in description.
* Fri Mar 23 2018 tchvatal@suse.com
- Cleanup with spec-cleaner
- Switch to github archive to have tests
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update to 1.0.1
  * allow unicode strings for variable name in Python 2
  * allow unicode strings as strength specifiers in Python 2
- Update to 1.0.0
  * Allow anonymous variables (solver PR #32, wrappers PR #22)
  * Solver: Define binary operators as free functions (PR #23)
  * Wrappers: support for Python 3 (PR #13)
  * Wrappers: drop distribute dependency in favor of setuptools (PR #22)
  * Wrappers: add a comprehensive test suite
- Implement single-spec version
- Complete spec file rewrite.
* Fri Sep  4 2015 toddrme2178@gmail.com
- Initial version
